Learn R Programming

T2Qv (version 0.2.0)

ACMconcatenated: ACM Concatenated

Description

Multiple correspondence analysis applied to a concatenated table.

Usage

ACMconcatenated(base, IndK, interactive = FALSE)

Value

A Multiple Correspondence Analysis graph of the concatenated table.

Arguments

base

Data set

IndK

Character with the name of the column that specifies the partition of the data set in k tables.

interactive

If it is TRUE, the graph will be shown interactively. If FALSE, the graph is displayed flat. FALSE is the default.

Examples

Run this code
data(Datak10Contaminated)
ACMconcatenated(Datak10Contaminated,"GroupLetter", interactive = FALSE)

Run the code above in your browser using DataLab