powered by
Multiple correspondence analysis applied to a concatenated table.
ACMconcatenated(base, IndK, interactive = FALSE)
A Multiple Correspondence Analysis graph of the concatenated table.
Data set
Character with the name of the column that specifies the partition of the data set in k tables.
If it is TRUE, the graph will be shown interactively. If FALSE, the graph is displayed flat. FALSE is the default.
data(Datak10Contaminated) ACMconcatenated(Datak10Contaminated,"GroupLetter", interactive = FALSE)
Run the code above in your browser using DataLab